--
-- TOC entry 234 (class 1255 OID 24860)
-- Name: func_config_edit(integer, text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION public.func_config_edit(_config_id integer, _name text, _period integer) RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
	_id INTEGER;
BEGIN
	IF _config_id = -1 THEN
		-- добавление
		INSERT INTO config
			(name, period, created, modified)
			VALUES
			(_name, _period, CURRENT_TIMESTAMP(3), CURRENT_TIMESTAMP(3))
			RETURNING id INTO _id;
	ELSE
		-- проверка существования записи узла для устройства
		IF EXISTS(SELECT 1 FROM config WHERE id = _config_id) THEN
			-- изменение в случае существования
			UPDATE config SET
				name = _name,
				period = _period,
				modified = CURRENT_TIMESTAMP(3)
			WHERE id = _config_id
			RETURNING id INTO _id;
		END IF;
	END IF;

	PERFORM pg_notify('snmp_changes'::text, 'config.id:'::text || _id::text);

	RETURN _id;
END;
$$;


ALTER FUNCTION public.func_config_edit(_config_id integer, _name text, _period integer) OWNER TO postgres;

--
-- TOC entry 237 (class 1255 OID 24861)
-- Name: func_config_remove(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION public.func_config_remove(_config_id integer) RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE _id integer;
BEGIN
	-- удаление устройства
	DELETE FROM config WHERE id = _config_id RETURNING id INTO _id;

	PERFORM pg_notify('snmp_changes'::text, 'config.id:'::text || _id::text);

	RETURN _id;
END;
$$;


ALTER FUNCTION public.func_config_remove(_config_id integer) OWNER TO postgres;

--
-- TOC entry 3437 (class 0 OID 0)
-- Dependencies: 237
-- Name: FUNCTION func_config_remove(_config_id integer); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION public.func_config_remove(_config_id integer) IS 'Удаление устройства';


--
-- TOC entry 238 (class 1255 OID 24995)
-- Name: func_device_delete(uuid); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION public.func_device_delete(_device_guid uuid) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
DECLARE _guid uuid;
BEGIN
	-- удаление устройства
	DELETE FROM devices WHERE guid = _device_guid RETURNING guid INTO _guid;

	PERFORM pg_notify('snmp_changes'::text, 'devices.guid:'::text || _guid::text);

	RETURN _guid;
END;
$$;


ALTER FUNCTION public.func_device_delete(_device_guid uuid) OWNER TO postgres;

--
-- TOC entry 3439 (class 0 OID 0)
-- Dependencies: 238
-- Name: FUNCTION func_device_delete(_device_guid uuid); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION public.func_device_delete(_device_guid uuid) IS 'Удаление устройства';


--
-- TOC entry 239 (class 1255 OID 24992)
-- Name: func_device_edit(uuid, character varying, character varying, integer, text, text, integer, text, integer, integer, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION public.func_device_edit(_device_guid uuid, _name character varying, _ipaddress character varying, _port integer, _filename text, _mib text, _version integer, _community text, _level integer, _authproto integer, _password text) RETURNS uuid
    LANGUAGE plpgsql
    AS $$
DECLARE _guid uuid;
BEGIN
	IF _device_guid IS NULL THEN
		SELECT gen_random_uuid() INTO _device_guid;
	END IF;
	IF NOT EXISTS(SELECT 1 FROM devices WHERE guid = _device_guid) THEN
		-- добавляем новое устройство
		INSERT INTO devices
			(guid, name, ip, port, filename, mib, version, security_name, security_level, security_auth_proto, pass_phrase)
		VALUES
			(_device_guid, _name, _ipaddress, _port, _filename, _mib, _version, _community, _level, _authproto, _password)
		RETURNING guid INTO _guid;
	ELSE
		-- вносим изменения в запись справочника устройств
		UPDATE devices
		SET
			name = _name,
			ip = _ipaddress,
			port = _port,
			filename = _filename,
			mib = _mib,
			version = _version,
			security_name = _community,
			security_level = _level,
			security_auth_proto = _authproto,
			pass_phrase = _password
		WHERE
			guid = _device_guid
		RETURNING guid INTO _guid;
	END IF;

	PERFORM pg_notify('snmp_changes'::text, 'devices.guid:'::text || _guid::text);

	RETURN _guid;
END;
$$;


ALTER FUNCTION public.func_device_edit(_device_guid uuid, _name character varying, _ipaddress character varying, _port integer, _filename text, _mib text, _version integer, _community text, _level integer, _authproto integer, _password text) OWNER TO postgres;

--
-- TOC entry 3441 (class 0 OID 0)
-- Dependencies: 239
-- Name: FUNCTION func_device_edit(_device_guid uuid, _name character varying, _ipaddress character varying, _port integer, _filename text, _mib text, _version integer, _community text, _level integer, _authproto integer, _password text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION public.func_device_edit(_device_guid uuid, _name character varying, _ipaddress character varying, _port integer, _filename text, _mib text, _version integer, _community text, _level integer, _authproto integer, _password text) IS 'Добавление/редактирование устройства';


--
-- TOC entry 242 (class 1255 OID 24993)
-- Name: func_device_nodes_add(integer, uuid, text, text, text, text, integer, integer, boolean, boolean, integer, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE OR REPLACE FUNCTION public.func_device_nodes_add(
        _config_id integer,
        _device_guid uuid,
        _path text,
        _name text,
        _description text,
        _alias text,
        _period integer,
        _value_type integer,
        _send_up boolean,
        _scalar boolean,
        _range_min integer,
        _range_max integer)
    RETURNS integer
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE PARALLEL UNSAFE
AS $BODY$
DECLARE
        _id INTEGER;
        _row_count INTEGER;
BEGIN
        -- проверка существования записи узла для устройства
        IF EXISTS(SELECT 1 FROM device_nodes WHERE config_id = _config_id AND devices_guid = _device_guid AND path = _path) THEN
                -- изменение в случае существования
                UPDATE device_nodes SET
                        config_id = _config_id,
                        devices_guid = _device_guid,
                        path = _path,
                        name = _name,
                        description = _description,
                        alias = _alias,
                        period = _period,
                        value_type = _value_type,
                        send_up = _send_up,
                        scalar = _scalar,
                        range_min = _range_min,
                        range_max = _range_max,
                        updated = CURRENT_TIMESTAMP(3)
                WHERE devices_guid = _device_guid AND path = _path
                RETURNING id INTO _id;
                --GET DIAGNOSTICS _row_count = row_count;
        ELSE
                -- добавление в случае отсутствия
                INSERT INTO device_nodes
                        (config_id, devices_guid, path, name, description, alias, period, value_type, send_up, scalar, range_min, range_max, created)
                        VALUES
                        (_config_id, _device_guid, _path, _name, _description, _alias, _period, _value_type, _send_up, _scalar, _range_min, _range_max, CURRENT_TIMESTAMP(3))
                        RETURNING id INTO _id;
        END IF;

        PERFORM pg_notify('snmp_changes'::text, 'device_nodes.id:'::text || _id::text);

        RETURN _id;
END;
$BODY$;


ALTER FUNCTION public.func_device_nodes_add(integer, uuid, text, text, text, text, integer, integer, boolean, boolean, integer, integer)
    OWNER TO postgres;

--
-- TOC entry 243 (class 1255 OID 25056)
-- Name: func_device_nodes_close_all_traps(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION public.func_device_nodes_close_all_traps() RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
	_id integer;
	_device text = NULL;
	_now TIMESTAMP WITH TIME ZONE;
BEGIN
	_now = CURRENT_TIMESTAMP(3);
	_id = -1;

	UPDATE traps
		SET closed = _now
	WHERE
		closed IS NULL;

	PERFORM pg_notify('snmp_changes'::text, 'traps.id:'::text || _id::text);

	RETURN _id;
END;
$$;


ALTER FUNCTION public.func_device_nodes_close_all_traps() OWNER TO postgres;

--
-- TOC entry 241 (class 1255 OID 25057)
-- Name: func_device_nodes_close_trap(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION public.func_device_nodes_close_trap(_trap_id integer) RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
	_id integer;
	_now TIMESTAMP WITH TIME ZONE;
BEGIN
	_now = CURRENT_TIMESTAMP(3);

	UPDATE traps
		SET closed = _now
	WHERE
		id = _trap_id
	RETURNING id INTO _id;


	PERFORM pg_notify('snmp_changes'::text, 'traps.id:'::text || _id::text);

	RETURN _id;
END;
$$;


ALTER FUNCTION public.func_device_nodes_close_trap(_trap_id integer) OWNER TO postgres;

--
-- TOC entry 236 (class 1255 OID 24836)
-- Name: func_device_nodes_edit(integer, text, text, integer, boolean); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION public.func_device_nodes_edit(
	_node_id integer,
	_path text,
	_alias text,
	_period integer,
	_send_up boolean)
    RETURNS integer
    LANGUAGE 'plpgsql'
    COST 100
    VOLATILE PARALLEL UNSAFE
AS $$
DECLARE
    _id INTEGER;
BEGIN
    -- проверка существования записи узла для устройства
    IF EXISTS(SELECT 1 FROM device_nodes WHERE id = _node_id AND path = _path) THEN
        -- изменение в случае существования
        UPDATE device_nodes SET
            period = _period,
			alias = _alias,
			send_up = _send_up
        WHERE id = _node_id AND path = _path
        RETURNING id INTO _id;
    ELSE
        RAISE EXCEPTION 'Запись с идентификатором [%] в [%] не существует!', _node_id, _path;
    END IF;

    PERFORM pg_notify('snmp_changes'::text, 'device_nodes.id:'::text || _id::text);

    RETURN _id;
END;
$$;

ALTER FUNCTION public.func_device_nodes_edit(integer, text, text, integer, boolean)
    OWNER TO postgres;


--
-- TOC entry 244 (class 1255 OID 25047)
-- Name: func_device_nodes_register_trap(text, text, integer, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION public.func_device_nodes_register_trap(_address text, _path text, _version integer, _value text) RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
	_id integer;
	_device text = NULL;
	_now TIMESTAMP WITH TIME ZONE;
BEGIN
	_now = CURRENT_TIMESTAMP(3);

	-- проверка существования записи узла для устройства
	SELECT
		name
	INTO _device
	FROM
		devices
	WHERE
		ip = _address
	LIMIT 1;

	INSERT INTO traps
		(happend, version, from_address, device_name, path, value, closed)
		VALUES
		(_now, _version, _address, _device, _path, _value, NULL)
	RETURNING id INTO _id;


	PERFORM pg_notify('snmp_changes'::text, 'traps.id:'::text || _id::text);

	RETURN _id;
END;
$$;


ALTER FUNCTION public.func_device_nodes_register_trap(_address text, _path text, _version integer, _value text) OWNER TO postgres;

--
-- TOC entry 240 (class 1255 OID 25031)
-- Name: func_device_nodes_register_value(integer, text, integer, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION public.func_device_nodes_register_value(_id integer, _path text, _value_type integer, _value_string text) RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
 	_history_id INTEGER;
	_now TIMESTAMP WITH TIME ZONE;
BEGIN
	-- проверка существования записи узла для устройства
	IF EXISTS(SELECT 1 FROM device_nodes WHERE id = _id AND path = _path) THEN
		_now = CURRENT_TIMESTAMP(3);
		-- изменение в случае существования
		UPDATE device_nodes SET
			value_string = _value_string,
			value_changed = _now
		WHERE id = _id AND path = _path;

		-- PERFORM pg_notify('snmp_changes'::text, 'device_nodes.id:'::text || _id::text);

		-- проверка существования открытого периода
		SELECT
			 id
		INTO
			_history_id
		FROM
			device_node_history
		WHERE
			device_nodes_id = _id AND finished IS NULL
		ORDER BY
			Started DESC
		LIMIT 1;

		IF _history_id IS NULL THEN		-- периодов нет или все закрыты
			-- добавляем новое значение и открываем период
			INSERT INTO device_node_history
				(device_nodes_id, value_type, value_string, written, started, finished)
				VALUES
				(_id, _value_type, _value_string, _now, _now, NULL)
				RETURNING id INTO _history_id;
		ELSE
			-- проверка текущего значения открытого периода
			IF NOT EXISTS(SELECT 1 FROM device_node_history WHERE id = _history_id AND value_string = _value_string) THEN
				-- закрываем период старого значения
				UPDATE  device_node_history SET
					 finished = _now
					,written = _now
				WHERE
					id = _history_id;
				-- открываем новый
				INSERT INTO device_node_history
					(device_nodes_id, value_type, value_string, written, started, finished)
					VALUES
					(_id, _value_type, _value_string, _now, _now, NULL)
					RETURNING id INTO _history_id;
			ELSE
				-- ни чего не изменилось, просто обновляем дату
				UPDATE  device_node_history SET
					written = _now
				WHERE
					id = _history_id;
			END IF;
		END IF;

		PERFORM pg_notify('snmp_changes'::text, 'device_node_history.device_nodes_id:'::text || _id::text);

	ELSE
		RAISE EXCEPTION 'Запись с идентификатором [%] в [%] не существует!', _id, _path;
	END IF;

	RETURN _history_id;
END;
$$;


ALTER FUNCTION public.func_device_nodes_register_value(_id integer, _path text, _value_type integer, _value_string text) OWNER TO postgres;

--
-- TOC entry 235 (class 1255 OID 24994)
-- Name: func_device_nodes_remove(integer, uuid, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION public.func_device_nodes_remove(_config_id integer, _device_guid uuid, _path text) RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
	_id INTEGER;
BEGIN
	-- удаление узла для опроса устройства
	DELETE FROM device_nodes
                WHERE config_id = _config_id AND devices_guid = _device_guid AND path = _path
		RETURNING id INTO _id;

	PERFORM pg_notify('snmp_changes'::text, 'device_nodes.id:'::text || _id::text);

	RETURN _id;
END;
$$;


ALTER FUNCTION public.func_device_nodes_remove(_config_id integer, _device_guid uuid, _path text) OWNER TO postgres;

--
-- TOC entry 3444 (class 0 OID 0)
-- Dependencies: 235
-- Name: FUNCTION func_device_nodes_remove(_config_id integer, _device_guid uuid, _path text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION public.func_device_nodes_remove(_config_id integer, _device_guid uuid, _path text) IS 'Удаление узла для опроса устройства';



CREATE FUNCTION public.func_device_nodes_remove(_node_id integer) RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
        _id INTEGER;
BEGIN
        -- удаление узла для опроса устройства
        DELETE FROM device_nodes
                WHERE id = _node_id
                RETURNING id INTO _id;

        PERFORM pg_notify('snmp_changes'::text, 'device_nodes.id:'::text || _id::text);

        RETURN _id;
END;
$$;


ALTER FUNCTION public.func_device_nodes_remove(_node_id integer) OWNER TO postgres;

COMMENT ON FUNCTION public.func_device_nodes_remove(_node_id integer) IS 'Удаление узла для опроса устройства';


--
-- TOC entry 222 (class 1255 OID 16552)
-- Name: func_logs_append(timestamp with time zone, character varying, integer, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION public.func_logs_append(_created timestamp with time zone, _code character varying, _number integer, _text text) RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
	_id INTEGER;
BEGIN
	-- поиск кода сообщения
	SELECT id INTO _id
		FROM log_types
		WHERE code = _code;
	-- проверка наличия кода сообщения
	IF _id IS NULL THEN
		RAISE EXCEPTION 'Тип сообщения % не найден', _code::text;
	END IF;

	INSERT INTO logs
		(created, log_types_id, "number", "text")
		VALUES
		(_created, _id, _number, _text)
		RETURNING id INTO _id;

	PERFORM pg_notify('snmp_changes'::text, 'logs.id:'::text || _id::text);

	RETURN _id;
END;
$$;


ALTER FUNCTION public.func_logs_append(_created timestamp with time zone, _code character varying, _number integer, _text text) OWNER TO postgres;

SET default_tablespace = '';

--SET default_table_access_method = heap;

--
-- TOC entry 215 (class 1259 OID 16643)
-- Name: config; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.config (
    id integer NOT NULL,
    name text NOT NULL,
    created timestamp with time zone,
    modified timestamp with time zone,
    period integer DEFAULT 3600
);


ALTER TABLE public.config OWNER TO postgres;

--
-- TOC entry 3446 (class 0 OID 0)
-- Dependencies: 215
-- Name: TABLE config; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE public.config IS 'Справочник конфигураций';


--
-- TOC entry 3447 (class 0 OID 0)
-- Dependencies: 215
-- Name: COLUMN config.period; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.config.period IS 'Период опроса по умолчанию';


--
-- TOC entry 3271 (class 2606 OID 16649)
-- Name: config config_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.config
    ADD CONSTRAINT config_pkey PRIMARY KEY (id);


--
-- TOC entry 216 (class 1259 OID 24862)
-- Name: config_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

ALTER TABLE public.config ALTER COLUMN id ADD GENERATED ALWAYS AS IDENTITY (
    SEQUENCE NAME public.config_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
);

--
-- TOC entry 217 (class 1259 OID 24925)
-- Name: devices; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.devices (
    guid uuid NOT NULL,
    name character varying(50) NOT NULL,
    ip character varying(15) NOT NULL,
    port integer NOT NULL,
    filename text NOT NULL,
    mib text NOT NULL,
    version integer,
    security_name text,
    security_level integer,
    security_auth_proto integer,
    pass_phrase text
);


ALTER TABLE public.devices OWNER TO postgres;

--
-- TOC entry 3469 (class 0 OID 0)
-- Dependencies: 217
-- Name: TABLE devices; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE public.devices IS 'Устройства';


--
-- TOC entry 3470 (class 0 OID 0)
-- Dependencies: 217
-- Name: COLUMN devices.guid; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.devices.guid IS 'Идентификатор';


--
-- TOC entry 3471 (class 0 OID 0)
-- Dependencies: 217
-- Name: COLUMN devices.name; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.devices.name IS 'Название устройства';


--
-- TOC entry 3472 (class 0 OID 0)
-- Dependencies: 217
-- Name: COLUMN devices.ip; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.devices.ip IS 'IP адрес устройства';


--
-- TOC entry 3473 (class 0 OID 0)
-- Dependencies: 217
-- Name: COLUMN devices.port; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.devices.port IS 'Порт SNMP протокола';


--
-- TOC entry 3474 (class 0 OID 0)
-- Dependencies: 217
-- Name: COLUMN devices.filename; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.devices.filename IS 'Путь к MIB файлу';


--
-- TOC entry 3475 (class 0 OID 0)
-- Dependencies: 217
-- Name: COLUMN devices.version; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.devices.version IS 'Версия SNMP-протокола';

--
-- TOC entry 3274 (class 2606 OID 24932)
-- Name: devices devices_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.devices
    ADD CONSTRAINT devices_pkey PRIMARY KEY (guid);


-- Table: public.device_nodes

-- DROP TABLE IF EXISTS public.device_nodes;

CREATE TABLE IF NOT EXISTS public.device_nodes
(
    id integer NOT NULL GENERATED ALWAYS AS IDENTITY ( INCREMENT 1 START 1 MINVALUE 1 MAXVALUE 2147483647 CACHE 1 ),
    devices_guid uuid NOT NULL,
    path text COLLATE pg_catalog."default" NOT NULL,
    name text COLLATE pg_catalog."default" NOT NULL,
    period integer NOT NULL,
    description text COLLATE pg_catalog."default" NOT NULL DEFAULT ''::text,
    created timestamp with time zone,
    updated timestamp with time zone,
    value_type integer,
    value_string text COLLATE pg_catalog."default",
    value_changed timestamp with time zone,
    scalar boolean DEFAULT true,
    range_min integer,
    range_max integer,
    config_id integer NOT NULL DEFAULT 1,
    alias text COLLATE pg_catalog."default",
    send_up boolean NOT NULL DEFAULT false,
    CONSTRAINT device_nodes_pkey PRIMARY KEY (id),
    CONSTRAINT device_nodes_unq_config_id_devices_guid_path UNIQUE (config_id, devices_guid, path),
    CONSTRAINT config_id FOREIGN KEY (config_id)
        REFERENCES public.config (id) MATCH SIMPLE
        ON UPDATE CASCADE
        ON DELETE CASCADE,
    CONSTRAINT devices_guid_fkey FOREIGN KEY (devices_guid)
        REFERENCES public.devices (guid) MATCH SIMPLE
        ON UPDATE NO ACTION
        ON DELETE NO ACTION
        NOT VALID
)

TABLESPACE pg_default;

ALTER TABLE IF EXISTS public.device_nodes
    OWNER to postgres;

GRANT ALL ON TABLE public.device_nodes TO postgres;

GRANT ALL ON TABLE public.device_nodes TO snmpmonitor;

COMMENT ON TABLE public.device_nodes
    IS 'Список отслеживаемых узлов устройств';

COMMENT ON COLUMN public.device_nodes.id
    IS 'Идентификатор';

COMMENT ON COLUMN public.device_nodes.devices_guid
    IS 'Идетификатор устройства';

COMMENT ON COLUMN public.device_nodes.path
    IS 'Путь к узлу';

COMMENT ON COLUMN public.device_nodes.name
    IS 'Имя узла';

COMMENT ON COLUMN public.device_nodes.period
    IS 'Период опроса параметра';

COMMENT ON COLUMN public.device_nodes.created
    IS 'Дата и время создания параметра';

COMMENT ON COLUMN public.device_nodes.updated
    IS 'Дата и время изменения значения параметра';

COMMENT ON COLUMN public.device_nodes.value_type
    IS 'Тип параметра';

COMMENT ON COLUMN public.device_nodes.value_string
    IS 'Значение параметра в строковом виде';

COMMENT ON COLUMN public.device_nodes.value_changed
    IS 'Дата и время фиксации последнего значения параметра';

COMMENT ON COLUMN public.device_nodes.scalar
    IS 'Тип параметра: скаларяный или табличный';

COMMENT ON COLUMN public.device_nodes.range_min
    IS 'Минимальное значение диапазона опроса баличного значения';

COMMENT ON COLUMN public.device_nodes.range_max
    IS 'Максимальное значение диапазона опроса баличного значения';

COMMENT ON COLUMN public.device_nodes.config_id
    IS 'Идентификатор конфигурации';

COMMENT ON COLUMN public.device_nodes.alias
    IS 'Псевдоним узла наблюдения';

COMMENT ON COLUMN public.device_nodes.send_up
    IS 'Флаг отправки значения во внешнюю систему';


--
-- TOC entry 209 (class 1259 OID 16553)
-- Name: device_node_history; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.device_node_history (
    id integer NOT NULL,
    device_nodes_id integer NOT NULL,
    value_type integer NOT NULL,
    value_string text NOT NULL,
    written timestamp with time zone NOT NULL,
    started timestamp with time zone,
    finished timestamp with time zone
);


ALTER TABLE public.device_node_history OWNER TO postgres;

--
-- TOC entry 3449 (class 0 OID 0)
-- Dependencies: 209
-- Name: TABLE device_node_history; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE public.device_node_history IS 'История изменения значений узлов';


--
-- TOC entry 3450 (class 0 OID 0)
-- Dependencies: 209
-- Name: COLUMN device_node_history.id; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.device_node_history.id IS 'Идетификатор';


--
-- TOC entry 3451 (class 0 OID 0)
-- Dependencies: 209
-- Name: COLUMN device_node_history.device_nodes_id; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.device_node_history.device_nodes_id IS 'Идентификатор записи узла';


--
-- TOC entry 3452 (class 0 OID 0)
-- Dependencies: 209
-- Name: COLUMN device_node_history.value_type; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.device_node_history.value_type IS 'Тип значения узла';


--
-- TOC entry 3453 (class 0 OID 0)
-- Dependencies: 209
-- Name: COLUMN device_node_history.value_string; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.device_node_history.value_string IS 'Строковое представление значения узла';


--
-- TOC entry 3454 (class 0 OID 0)
-- Dependencies: 209
-- Name: COLUMN device_node_history.written; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.device_node_history.written IS 'Дата и время записи значения узла';


--
-- TOC entry 210 (class 1259 OID 16558)
-- Name: device_node_history_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

ALTER TABLE public.device_node_history ALTER COLUMN id ADD GENERATED ALWAYS AS IDENTITY (
    SEQUENCE NAME public.device_node_history_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
);



--
-- TOC entry 211 (class 1259 OID 16571)
-- Name: log_types; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.log_types (
    id integer NOT NULL,
    code character varying(4) NOT NULL,
    name text NOT NULL
);


ALTER TABLE public.log_types OWNER TO postgres;

--
-- TOC entry 3477 (class 0 OID 0)
-- Dependencies: 211
-- Name: TABLE log_types; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE public.log_types IS 'Типы сообщений протокола работы системы';


--
-- TOC entry 3478 (class 0 OID 0)
-- Dependencies: 211
-- Name: COLUMN log_types.id; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.log_types.id IS 'Идентификатор';


--
-- TOC entry 3479 (class 0 OID 0)
-- Dependencies: 211
-- Name: COLUMN log_types.code; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.log_types.code IS 'Код типа сообшения';


--
-- TOC entry 3480 (class 0 OID 0)
-- Dependencies: 211
-- Name: COLUMN log_types.name; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.log_types.name IS 'Название типа сообщения';


--
-- TOC entry 212 (class 1259 OID 16576)
-- Name: log_types_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

ALTER TABLE public.log_types ALTER COLUMN id ADD GENERATED ALWAYS AS IDENTITY (
    SEQUENCE NAME public.log_types_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
);


--
-- TOC entry 213 (class 1259 OID 16577)
-- Name: logs; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.logs (
    id integer NOT NULL,
    created timestamp(3) with time zone NOT NULL,
    log_types_id integer NOT NULL,
    number integer NOT NULL,
    text text NOT NULL
);


ALTER TABLE public.logs OWNER TO postgres;

--
-- TOC entry 3483 (class 0 OID 0)
-- Dependencies: 213
-- Name: TABLE logs; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE public.logs IS 'Сообщения протокола работы системы';


--
-- TOC entry 3484 (class 0 OID 0)
-- Dependencies: 213
-- Name: COLUMN logs.id; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.logs.id IS 'Идентификатор';


--
-- TOC entry 3485 (class 0 OID 0)
-- Dependencies: 213
-- Name: COLUMN logs.created; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.logs.created IS 'Дата и время события';


--
-- TOC entry 3486 (class 0 OID 0)
-- Dependencies: 213
-- Name: COLUMN logs.log_types_id; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.logs.log_types_id IS 'Идентификатор типа события';


--
-- TOC entry 3487 (class 0 OID 0)
-- Dependencies: 213
-- Name: COLUMN logs.number; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.logs.number IS 'Номер типа сообщения';


--
-- TOC entry 3488 (class 0 OID 0)
-- Dependencies: 213
-- Name: COLUMN logs.text; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON COLUMN public.logs.text IS 'Текст сообщения';


--
-- TOC entry 214 (class 1259 OID 16582)
-- Name: logs_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

ALTER TABLE public.logs ALTER COLUMN id ADD GENERATED ALWAYS AS IDENTITY (
    SEQUENCE NAME public.logs_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
);


--
-- TOC entry 220 (class 1259 OID 25038)
-- Name: traps; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE public.traps (
    happend timestamp with time zone DEFAULT CURRENT_TIMESTAMP(3) NOT NULL,
    version integer DEFAULT 1 NOT NULL,
    from_address character varying(50) NOT NULL,
    device_name character varying(50),
    path text NOT NULL,
    value text,
    closed timestamp with time zone,
    id integer NOT NULL
);


ALTER TABLE public.traps OWNER TO postgres;

--
-- TOC entry 221 (class 1259 OID 25048)
-- Name: traps_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

ALTER TABLE public.traps ALTER COLUMN id ADD GENERATED ALWAYS AS IDENTITY (
    SEQUENCE NAME public.traps_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1
);

--
-- TOC entry 3257 (class 2606 OID 16584)
-- Name: device_node_history device_node_history_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.device_node_history
    ADD CONSTRAINT device_node_history_pkey PRIMARY KEY (id);


--
-- TOC entry 3261 (class 2606 OID 16592)
-- Name: log_types log_types_code_unq; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.log_types
    ADD CONSTRAINT log_types_code_unq UNIQUE (code);


--
-- TOC entry 3263 (class 2606 OID 16594)
-- Name: log_types log_types_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.log_types
    ADD CONSTRAINT log_types_pkey PRIMARY KEY (id);


--
-- TOC entry 3269 (class 2606 OID 16596)
-- Name: logs logs_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.logs
    ADD CONSTRAINT logs_pkey PRIMARY KEY (id);


--
-- TOC entry 3272 (class 1259 OID 24933)
-- Name: devices_idx_name; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX devices_idx_name ON public.devices USING btree (name);


--
-- TOC entry 3275 (class 1259 OID 24996)
-- Name: devices_unq_ip_port_community; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX devices_unq_ip_port_community ON public.devices USING btree (ip, port, security_name);


--
-- TOC entry 3281 (class 1259 OID 24973)
-- Name: fki_device_nodes_fkey_devices; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX fki_device_nodes_fkey_devices ON public.device_nodes USING btree (devices_guid);


--
-- TOC entry 3258 (class 1259 OID 16600)
-- Name: fki_device_nodes_history_fkey_device_nodes; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX fki_device_nodes_history_fkey_device_nodes ON public.device_node_history USING btree (device_nodes_id);


--
-- TOC entry 3259 (class 1259 OID 24989)
-- Name: fki_device_nodes_id_fkey; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX fki_device_nodes_id_fkey ON public.device_node_history USING btree (device_nodes_id);


--
-- TOC entry 3282 (class 1259 OID 24983)
-- Name: fki_devices_guid_fkey; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX fki_devices_guid_fkey ON public.device_nodes USING btree (devices_guid);


--
-- TOC entry 3264 (class 1259 OID 16601)
-- Name: fki_logs_fk_log_types; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX fki_logs_fk_log_types ON public.logs USING btree (log_types_id);


--
-- TOC entry 3287 (class 1259 OID 25045)
-- Name: happend_idx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX happend_idx ON public.traps USING btree (happend) INCLUDE (from_address);

ALTER TABLE public.traps CLUSTER ON happend_idx;


--
-- TOC entry 3283 (class 1259 OID 24974)
-- Name: idx_device_nodes_name; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX idx_device_nodes_name ON public.device_nodes USING btree (name);


--
-- TOC entry 3284 (class 1259 OID 24975)
-- Name: idx_device_nodes_path; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX idx_device_nodes_path ON public.device_nodes USING btree (path);


--
-- TOC entry 3285 (class 1259 OID 24976)
-- Name: idx_device_nodes_value_string; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX idx_device_nodes_value_string ON public.device_nodes USING btree (value_string);


--
-- TOC entry 3286 (class 1259 OID 24977)
-- Name: idx_device_nodes_value_type; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX idx_device_nodes_value_type ON public.device_nodes USING btree (value_type);


--
-- TOC entry 3265 (class 1259 OID 16606)
-- Name: idx_logs_created; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX idx_logs_created ON public.logs USING btree (created);


--
-- TOC entry 3266 (class 1259 OID 16607)
-- Name: idx_logs_number; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX idx_logs_number ON public.logs USING btree (number);


--
-- TOC entry 3267 (class 1259 OID 16608)
-- Name: idx_logs_text; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX idx_logs_text ON public.logs USING btree (text);


--
-- TOC entry 3288 (class 2606 OID 24997)
-- Name: device_node_history device_nodes_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.device_node_history
    ADD CONSTRAINT device_nodes_id_fkey FOREIGN KEY (device_nodes_id) REFERENCES public.device_nodes(id) ON UPDATE CASCADE ON DELETE CASCADE NOT VALID;


--
-- TOC entry 3289 (class 2606 OID 16619)
-- Name: logs logs_fk_log_types; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY public.logs
    ADD CONSTRAINT logs_fk_log_types FOREIGN KEY (log_types_id) REFERENCES public.log_types(id) ON UPDATE CASCADE ON DELETE CASCADE NOT VALID;


--
-- TOC entry 3438 (class 0 OID 0)
-- Dependencies: 237
-- Name: FUNCTION func_config_remove(_config_id integer); Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON FUNCTION public.func_config_remove(_config_id integer) FROM PUBLIC;
GRANT ALL ON FUNCTION public.func_config_remove(_config_id integer) TO snmpmonitor;


--
-- TOC entry 3440 (class 0 OID 0)
-- Dependencies: 238
-- Name: FUNCTION func_device_delete(_device_guid uuid); Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON FUNCTION public.func_device_delete(_device_guid uuid) FROM PUBLIC;
GRANT ALL ON FUNCTION public.func_device_delete(_device_guid uuid) TO snmpmonitor;


--
-- TOC entry 3442 (class 0 OID 0)
-- Dependencies: 239
-- Name: FUNCTION func_device_edit(_device_guid uuid, _name character varying, _ipaddress character varying, _port integer, _filename text, _mib text, _version integer, _community text, _level integer, _authproto integer, _password text); Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON FUNCTION public.func_device_edit(_device_guid uuid, _name character varying, _ipaddress character varying, _port integer, _filename text, _mib text, _version integer, _community text, _level integer, _authproto integer, _password text) FROM PUBLIC;
GRANT ALL ON FUNCTION public.func_device_edit(_device_guid uuid, _name character varying, _ipaddress character varying, _port integer, _filename text, _mib text, _version integer, _community text, _level integer, _authproto integer, _password text) TO snmpmonitor;


--
-- TOC entry 3443 (class 0 OID 0)
-- Dependencies: 236
-- Name: FUNCTION func_device_nodes_edit(_node_id integer, _path text, _alias text, _period integer, _send_up boolean); Type: ACL; Schema: public; Owner: postgres
--

GRANT ALL ON FUNCTION public.func_device_nodes_edit(_node_id integer, _path text, _alias text, _period integer, _send_up boolean) TO snmpmonitor;


--
-- TOC entry 3445 (class 0 OID 0)
-- Dependencies: 235
-- Name: FUNCTION func_device_nodes_remove(_config_id integer, _device_guid uuid, _path text); Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON FUNCTION public.func_device_nodes_remove(_config_id integer, _device_guid uuid, _path text) FROM PUBLIC;
GRANT ALL ON FUNCTION public.func_device_nodes_remove(_config_id integer, _device_guid uuid, _path text) TO snmpmonitor;

REVOKE ALL ON FUNCTION public.func_device_nodes_remove(_node_id integer) FROM PUBLIC;
GRANT ALL ON FUNCTION public.func_device_nodes_remove(_node_id_id integer) TO snmpmonitor;


--
-- TOC entry 3448 (class 0 OID 0)
-- Dependencies: 215
-- Name: TABLE config; Type: ACL; Schema: public; Owner: postgres
--

GRANT ALL ON TABLE public.config TO snmpmonitor;


--
-- TOC entry 3455 (class 0 OID 0)
-- Dependencies: 209
-- Name: TABLE device_node_history; Type: ACL; Schema: public; Owner: postgres
--

GRANT ALL ON TABLE public.device_node_history TO snmpmonitor;


--
-- TOC entry 3468 (class 0 OID 0)
-- Dependencies: 219
-- Name: TABLE device_nodes; Type: ACL; Schema: public; Owner: postgres
--

GRANT ALL ON TABLE public.device_nodes TO snmpmonitor;


--
-- TOC entry 3476 (class 0 OID 0)
-- Dependencies: 217
-- Name: TABLE devices; Type: ACL; Schema: public; Owner: postgres
--

GRANT ALL ON TABLE public.devices TO snmpmonitor;


--
-- TOC entry 3481 (class 0 OID 0)
-- Dependencies: 211
-- Name: TABLE log_types; Type: ACL; Schema: public; Owner: postgres
--

GRANT ALL ON TABLE public.log_types TO snmpmonitor;


--
-- TOC entry 3482 (class 0 OID 0)
-- Dependencies: 212
-- Name: SEQUENCE log_types_id_seq; Type: ACL; Schema: public; Owner: postgres
--

GRANT ALL ON SEQUENCE public.log_types_id_seq TO snmpmonitor;


--
-- TOC entry 3489 (class 0 OID 0)
-- Dependencies: 213
-- Name: TABLE logs; Type: ACL; Schema: public; Owner: postgres
--

GRANT ALL ON TABLE public.logs TO snmpmonitor;


--
-- TOC entry 3490 (class 0 OID 0)
-- Dependencies: 214
-- Name: SEQUENCE logs_id_seq; Type: ACL; Schema: public; Owner: postgres
--

GRANT ALL ON SEQUENCE public.logs_id_seq TO snmpmonitor;


--
-- TOC entry 3491 (class 0 OID 0)
-- Dependencies: 220
-- Name: TABLE traps; Type: ACL; Schema: public; Owner: postgres
--

GRANT ALL ON TABLE public.traps TO snmpmonitor;


-- Completed on 2022-10-21 11:26:32 MSK

--
-- PostgreSQL database dump complete
--

INSERT INTO public.log_types OVERRIDING SYSTEM VALUE VALUES (1, 'ERR', 'Ошибка');
INSERT INTO public.log_types OVERRIDING SYSTEM VALUE VALUES (2, 'WRN', 'Предупреждение');
INSERT INTO public.log_types OVERRIDING SYSTEM VALUE VALUES (3, 'MSG', 'Сообщение');
INSERT INTO public.log_types OVERRIDING SYSTEM VALUE VALUES (4, 'DBG', 'Отладка');
